import { unwrapTransformer } from "./transforms.js";
const _importShikiCore = cached(() => import("shiki/core"));
const _importShikiOptions = cached(() => import("shiki-options.mjs"));
const createCacheStore = (args) => {
  const globalCache = globalThis.__NUXT_SHIKI__ ??= {};
  const key = args[0] || "default";
  return globalCache[key] ??= {};
};
export const createHighlighter = cached(
  async () => {
    const [{ createHighlighterCore, createJavaScriptRegexEngine }, { shikiOptions }] = await Promise.all([
      _importShikiCore(),
      _importShikiOptions()
    ]);
    const highlighter = await createHighlighterCore({
      ...shikiOptions.core,
      engine: createJavaScriptRegexEngine()
    });
    highlighter.highlight = (code, highlightOptions) => {
      return highlighter.codeToHtml(code, resolveOptions(shikiOptions, highlightOptions));
    };
    return highlighter;
  },
  createCacheStore
);
export const createOptions = cached(
  async () => {
    const { shikiOptions } = await _importShikiOptions();
    return shikiOptions;
  },
  createCacheStore
);
export function resolveOptions(shikiOptions, highlightOptions = {}) {
  return {
    ...shikiOptions.highlight,
    ...highlightOptions,
    transformers: [
      ...highlightOptions.unwrap ? [unwrapTransformer] : [],
      ...highlightOptions.transformers || []
    ]
  };
}
function cached(fn, getStore) {
  const _store = getStore ? void 0 : {};
  return function(...args) {
    const store = _store || getStore(args);
    if (store.value !== void 0) {
      return store.value;
    }
    if (store.promise) {
      return store.promise;
    }
    const res = fn(...args);
    if (res instanceof Promise) {
      store.promise = res.then((value) => {
        store.value = value;
        delete store.promise;
        return value;
      });
      return store.promise;
    }
    return store.promise;
  };
}
